@@ -470,10 +470,11 @@ class opensshStatus(StatusMenuItem):
             if self.wlanIP in line:
                 countAllWLAN += 1
         countInWLAN = 0
-        for line in sshNetstat:
-            element = " ".join(line.split()).split()[3]
-            if self.wlanIP + ":ssh" in element:
-                countInWLAN += 1
+        if countAllWLAN:
+            for line in sshNetstat:
+                element = " ".join(line.split()).split()[3]
+                if self.wlanIP + ":ssh" in element:
+                    countInWLAN += 1
         countOutWLAN = countAllWLAN - countInWLAN
         
         countAllUSB = 0
@@ -481,10 +482,11 @@ class opensshStatus(StatusMenuItem):
             if self.usbIP in line:
                 countAllUSB += 1
         countInUSB = 0
-        for line in sshNetstat:
-            element = " ".join(line.split()).split()[3]
-            if self.usbIP + ":ssh" in element:
-                countInUSB += 1
+        if countAllUSB:
+            for line in sshNetstat:
+                element = " ".join(line.split()).split()[3]
+                if self.usbIP + ":ssh" in element:
+                    countInUSB += 1
         countOutUSB = countAllUSB - countInUSB
         
         self.sshConnected = countInWLAN + countInUSB
@@ -1013,10 +1015,11 @@ class opensshStatus(StatusMenuItem):
             if self.wlanIP in line:
                 countAllWLAN += 1
         countInWLAN = 0
-        for line in sshNetstat:
-            element = " ".join(line.split()).split()[3]
-            if self.wlanIP + ":ssh" in element:
-                countInWLAN += 1
+        if countAllWLAN:
+            for line in sshNetstat:
+                element = " ".join(line.split()).split()[3]
+                if self.wlanIP + ":ssh" in element:
+                    countInWLAN += 1
         countOutWLAN = countAllWLAN - countInWLAN
         self.labelCountInWLAN = countInWLAN
         self.labelCountOutWLAN = countOutWLAN
@@ -1026,10 +1029,11 @@ class opensshStatus(StatusMenuItem):
             if self.usbIP in line:
                 countAllUSB += 1
         countInUSB = 0
-        for line in sshNetstat:
-            element = " ".join(line.split()).split()[3]
-            if self.usbIP + ":ssh" in element:
-                countInUSB += 1
+        if countAllUSB:
+            for line in sshNetstat:
+                element = " ".join(line.split()).split()[3]
+                if self.usbIP + ":ssh" in element:
+                    countInUSB += 1
         countOutUSB = countAllUSB - countInUSB
         self.labelCountInUSB = countInUSB
         self.labelCountOutUSB = countOutUSB
